@@ -1,4 +1,4 @@
-/* Copyright © 2007-2019 Jakub Wilk <jwilk@jwilk.net>
+/* Copyright © 2007-2020 Jakub Wilk <jwilk@jwilk.net>
  * Copyright © 2009 Mateusz Turcza
  *
  * This file is part of pdf2djvu.
@@ -48,7 +48,11 @@
  * ======================
  */
 
+#if POPPLER_VERSION >= 8500
+static void poppler_error_handler(ErrorCategory category, pdf::Offset pos, const char *message)
+#else
 static void poppler_error_handler(void *data, ErrorCategory category, pdf::Offset pos, const char *message)
+#endif
 {
   std::string format;
   const char *category_name = _("PDF error");
@@ -108,7 +112,11 @@ pdf::Environment::Environment()
 #else
   globalParams = new GlobalParams;
 #endif
+#if POPPLER_VERSION >= 8500
+  setErrorCallback(poppler_error_handler);
+#else
   setErrorCallback(poppler_error_handler, nullptr);
+#endif
 }
 
 void pdf::Environment::set_antialias(bool value)
